function SpeakerStruct = praat_textgrid_parser(spkrlabels_fname)
%PRAAT_TEXTGRID_PARSER Goes through the annotations generated by Praat
% Converts the TextGrid information for 1 tier as labeled in Praat to a
% structure containing the start-time, end-time and the labeled text
%
% Author: Makarand Tapaswi
% Last modified: 30-01-2012

% Generate the mat files of the speaker labels
fprintf('Parsing through praat textgrid to extract speaker labels\n');
readme = fopen(spkrlabels_fname, 'r');

nextline = fgetl(readme);
while ischar(nextline)
    nextline = fgetl(readme);

    if strfind(nextline,'intervals: size')
        % parse number of intervals
        numintervals = str2double(nextline(strfind(nextline,'=')+2:end));
        % create space for storing information
        SpeakerStruct = struct;
    end

    if strfind(nextline,'intervals [')
        % parse interval number
        intnum = str2double(nextline(strfind(nextline,'[')+1:strfind(nextline,']')-1));

        % parse xmin
        nextline = fgetl(readme);
        SpeakerStruct(intnum).startpt = str2double(nextline(strfind(nextline,'=')+2:end));

        % parse xmax
        nextline = fgetl(readme);
        SpeakerStruct(intnum).endpt = str2double(nextline(strfind(nextline,'=')+2:end));

        % parse text
        nextline = fgetl(readme);        
        SpeakerStruct(intnum).label = lower(nextline(strfind(nextline,'=')+3:end-2));

        fprintf('%4d: Added: %0.4f : %0.4f : %s\n', intnum, ...
                                                    SpeakerStruct(intnum).startpt, ...
                                                    SpeakerStruct(intnum).endpt, ...
                                                    SpeakerStruct(intnum).label);
    end
end

fclose(readme);
    
end